Messages class

Constructors

Messages(BaseClient client, String baseUrl)

Properties

baseUrl → String
final
client → BaseClient
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

create(String server, MessageCreateOptions options) → Future<Message>
delete(String id) → Future<void>
deleteAll(String server) → Future<void>
forward(String id, MessageForwardOptions options) → Future<Message>
generatePreviews(String id, PreviewRequestOptions options) → Future<PreviewListResult>
get(String server, SearchCriteria criteria, {int timeout = 10000, int? receivedAfter, String? dir}) → Future<Message>
getById(String id) → Future<Message>
list(String server, {int? page, int? itemsPerPage, int? receivedAfter, String? dir}) → Future<MessageListResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reply(String id, MessageReplyOptions options) → Future<Message>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited